@@ -5,5 +5,5 @@ This is a wrapper class for the Tensorflow's Tensorboard application.
 """
 
 __version__ = "0.1"
-__author__ = 'Nathan Gavenski'
-__credits__ = 'Machine Learning Theory and Applications Lab"
+__author__ = "Nathan Gavenski"
+__credits__ = "Machine Learning Theory and Applications Lab"
